@@ -293,6 +293,8 @@ class Mobility(object):
     def __init__(self, day=None, window=30):
         path = join(dirname(__file__), "data", "state.dict")
         self._states = load_model(path)
+        path = join(dirname(__file__), "data", "bbox_country.dict")
+        self._n_states = load_model(path)
         self._bbox = BoundingBox()
         self._dates = list()
         delta = datetime.timedelta(days=1)
@@ -365,6 +367,9 @@ class Mobility(object):
                 return None
             return res[:2]
         try:
+            xx = self._n_states.get(label[:2], set())
+            if label in xx:
+                return None
             return self._states[label]
         except KeyError:
             return None
@@ -454,19 +459,15 @@ class Mobility(object):
                     if dest_code == ori_code:
                         matriz.update({ori_code: cnt})
             output.append(matriz)
-        return self.fill_with_zero(output)        
+        return self.fill_with_zero(output)
 
-    def outward(self, level=None):
+    def inside_outward(self, level):
         """
-        Outward mobility in an origin-destination matrix
-        
+        Inside and outward mobility
+
         :param level: Aggregation function
-        :rtype: list
         """
 
-        if level is None:
-            level = self.country
-
         output = []
         for day in self.travel_matrices:
             matrix = defaultdict(Counter)
@@ -483,6 +484,24 @@ class Mobility(object):
             output.append(matrix)
         return output
 
+    def outward(self, level=None):
+        """
+        Outward mobility in an origin-destination matrix
+        
+        :param level: Aggregation function
+        :rtype: list
+        """
+
+        if level is None:
+            level = self.country
+
+        output = self.inside_outward(level=level)
+        for data in output:
+          for k, dest in data.items():
+            if k in dest:
+              del dest[k]
+        return output
+
     def group_by_weekday(self, data):
         """
         Group the data by weekday works on a list of dictionaries
